==> PySwapper-1.1.tar.gz: PySwapper-1.1/setup.py <==
import setuptools
from distutils.core import setup
setup(
  name = 'PySwapper',         # How you named your package folder (MyLib)
  packages = ['PySwapper'],   # Chose the same as "name"
  version = '1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'stores variables in disk.',   # Give a short description about your library
  author = 'mohammad-sh-845',                   # Type in your name
  author_email = 'mohammad85sh.ir@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/mohammad-sh-845/',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/mohammad-sh-845/swapper/archive/refs/tags/1.0.tar.gz',    # I explain this later on
  keywords = ['swap', 'disk'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8'
  ],
)

==> PySwapper-1.1.1.tar.gz: PySwapper-1.1.1/setup.py <==
import setuptools
from distutils.core import setup
setup(
  name = 'PySwapper',         # How you named your package folder (MyLib)
  packages = ['PySwapper'],   # Chose the same as "name"
  version = '1.1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'stores variables in disk.',   # Give a short description about your library
  author = 'mohammad-sh-845',                   # Type in your name
  author_email = 'mohammad85sh.ir@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/mohammad-sh-845/',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/mohammad-sh-845/swapper/archive/refs/tags/1.0.tar.gz',    # I explain this later on
  keywords = ['swap', 'disk'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8'
  ],
)
